@@ -1,4 +1,4 @@
-<?xml version="1.0" encoding="iso-8859-1"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <tagger name="french">
 <tagset>
   <def-label name="ACRONIMOM">
@@ -368,6 +368,10 @@
     <label-sequence>
       <label-item label="DETM"/>
       <label-item label="VSERGER"/>
+    </label-sequence>     
+    <label-sequence>
+      <label-item label="DETM"/>
+      <label-item label="VSERINF"/>
     </label-sequence>
     <label-sequence>
       <label-item label="DETM"/>
@@ -433,6 +437,10 @@
       <label-item label="DETF"/>
       <label-item label="VLEXGER"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="DETF"/>
+      <label-item label="VLEXINF"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="DETF"/>
       <label-item label="VSERPFCI"/>
@@ -1264,16 +1272,24 @@
       <label-set>
         <label-item label="VLEXPFCI"/>
         <label-item label="VLEXIPI"/>
+	<label-item label="VLEXINF"/>
+	<label-item label="VLEXGER"/>
         <label-item label="VLEXSUBJ"/>
         <label-item label="VSERPFCI"/>
         <label-item label="VSERIPI"/>
-        <label-item label="VSERSUBJ"/>
+        <label-item label="VSERSUBJ"/>        
+	<label-item label="VSERINF"/>
+        <label-item label="VSERGER"/>
         <label-item label="VHABERPFCI"/>
         <label-item label="VHABERIPI"/>
-        <label-item label="VHABERSUBJ"/>
+        <label-item label="VHABERSUBJ"/>        
+	<label-item label="VHABERINF"/>
+        <label-item label="VHABERGER"/>
         <label-item label="VMODALPFCI"/>
         <label-item label="VMODALIPI"/>
-        <label-item label="VMODALSUBJ"/>
+        <label-item label="VMODALSUBJ"/>  
+	<label-item label="VMODALINF"/>
+        <label-item label="VMODALGER"/>
       </label-set>
     </enforce-after>
     <enforce-after label="PRNTN">
@@ -1282,4 +1298,28 @@
       </label-set>
    </enforce-after>
   </enforce-rules>
+  
+  <preferences>
+   <prefer tags="vblex.pri.p3.sg"/>
+   <prefer tags="vbser.pri.p3.sg"/>
+   <prefer tags="vbhaver.pri.p3.sg"/>
+   <prefer tags="vbmod.pri.p3.sg"/>  
+   <prefer tags="vblex.pii.p3.sg"/>
+   <prefer tags="vbser.pii.p3.sg"/>
+   <prefer tags="vbhaver.pii.p3.sg"/>
+   <prefer tags="vbmod.pii.p3.sg"/>
+   <prefer tags="vblex.prs.p3.sg"/>
+   <prefer tags="vbser.prs.p3.sg"/>
+   <prefer tags="vbhaver.prs.p3.sg"/>
+   <prefer tags="vbmod.prs.p3.sg"/>
+   <prefer tags="vblex.cni.p3.sg"/>
+   <prefer tags="vbser.cni.p3.sg"/>
+   <prefer tags="vbhaver.cni.p3.sg"/>
+   <prefer tags="vbmod.cni.p3.sg"/>
+   <prefer tags="vblex.pis.p3.sg"/>
+   <prefer tags="vbser.pis.p3.sg"/>
+   <prefer tags="vbhaver.pis.p3.sg"/>
+   <prefer tags="vbmod.pis.p3.sg"/>
+  </preferences>
+  
 </tagger>
